==> haskell-wizards-1.0.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wizards
version: 1.0.2
id: wizards-1.0.2-9TONZNhBSpX1j74ya4mNwV
key: wizards-1.0.2-9TONZNhBSpX1j74ya4mNwV
license: BSD-3-Clause
maintainer: liamoc@cse.unsw.edu.au
author: Liam O'\''Connor-Davis
synopsis: High level, generic library for interrogative user interfaces
description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.
    .
    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.
    .
    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.
    .
    .
    See the github page for examples on usage:
    .
    <http://www.github.com/liamoc/wizards>
    .
    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.
category: User Interfaces
abi: ffb60dd7ef49b76a3bfba55de2f13c27
exposed: True
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/wizards-1.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/wizards-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wizards-1.0.2
hs-libraries: HSwizards-1.0.2-9TONZNhBSpX1j74ya4mNwV
depends:
    base-4.11.1.0 containers-0.5.11.0
    control-monad-free-0.6.1-64fD2vBsrr9nRjiHlGguM haskeline-0.7.4.2
    mtl-2.2.2 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             control-monad-free-0.6.1-64fD2vBsrr9nRjiHlGguM=7954365acac89952d05c354f85e56486
             haskeline-0.7.4.2=e6153d219f5fb7b64fb712b63f016a25
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html: /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wizards-1.0.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wizards.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wizards
version: 1.0.2
id: wizards-1.0.2-BWDcYzYUxTC2yQYPYO6I9U
key: wizards-1.0.2-BWDcYzYUxTC2yQYPYO6I9U
license: BSD-3-Clause
maintainer: liamoc@cse.unsw.edu.au
author: Liam O'\''Connor-Davis
synopsis: High level, generic library for interrogative user interfaces
description:
    @wizards@ is a package designed for the quick and painless development of /interrogative/ programs, which
    revolve around a \"dialogue\" with the user, who is asked a series of questions in a sequence much like an
    installation wizard.
    .
    Everything from interactive system scripts, to installation wizards, to full-blown shells can be implemented with
    the support of @wizards@.
    .
    It is developed transparently on top of a free monad, which separates out the semantics of the program from any
    particular interface. A variety of backends exist, including console-based "System.Console.Wizard.Haskeline" and
    "System.Console.Wizard.BasicIO", and the pure "System.Console.Wizard.Pure". It is also possible to write your
    own backends, or extend existing back-ends with new features. While both built-in IO backends operate on a
    console, there is no reason why @wizards@ cannot also be used for making GUI wizard interfaces.
    .
    .
    See the github page for examples on usage:
    .
    <http://www.github.com/liamoc/wizards>
    .
    For creating backends, the module "System.Console.Wizard.Internal" has a brief tutorial.
category: User Interfaces
abi: ec51e03ce7452d1c8bde5bd6580a5ce7
exposed: True
exposed-modules:
    System.Console.Wizard System.Console.Wizard.BasicIO
    System.Console.Wizard.Haskeline System.Console.Wizard.Internal
    System.Console.Wizard.Pure
import-dirs: /usr/lib/ghc-8.6.1/site-local/wizards-1.0.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/wizards-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/wizards-1.0.2
hs-libraries: HSwizards-1.0.2-BWDcYzYUxTC2yQYPYO6I9U
depends:
    base-4.12.0.0 containers-0.6.0.1
    control-monad-free-0.6.2-K5OsWkYY4J3IMyPprITsgT haskeline-0.7.4.3
    mtl-2.2.2 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-wizards/html/wizards.haddock
haddock-html: /usr/share/doc/haskell-wizards/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
